@@ -275,6 +275,12 @@ class Currency:
     The `decimal_places` value must be greater or equal to 0 (zero).
     Negative values will be converter to 0 (zero).
 
+    The `convertion` string, when set, will be used to replace the
+    Western Arabic numerals - as well as the symbols - with the
+    equivalent ones on the currency language. The string must be
+    created with the numbers from 0 (zero) to 9 (nine) followed by the
+    minus sign without any separation mark (e.g.: '0123456789-').
+
     Args:
         amount (Union[int, float, Decimal]): Represented value.
         alpha_code (str, optionsl): Represented currency alpha code.
@@ -294,11 +300,14 @@ class Currency:
         international (bool, optional): Identifies the currency using
             the 'currency' value instead of the 'symbol'. Defaults to
             False.
+        convertion (str, optional): String with the numbers from 0 to 9
+            followed by the minus ('-') sign. Defaults to ''.
     """
 
     __slots__ = [
         '_alpha_code',
         '_amount',
+        '_convertion',
         '_decimal_places',
         '_decimal_sign',
         '_grouping_sign',
@@ -319,6 +328,7 @@ class Currency:
             decimal_places: Optional[int] = 2,
             decimal_sign: Optional[str] = '.',
             grouping_sign: Optional[str] = ',',
+            convertion: Optional[str] = '',
             international: Optional[bool] = False) -> 'Currency':
         """Class creator.
 
@@ -336,6 +346,7 @@ class Currency:
         self._symbol = symbol
         self._symbol_ahead = symbol_ahead
         self._symbol_separator = symbol_separator
+        self._convertion = convertion
         return self
 
     def __abs__(self) -> 'Currency':
@@ -357,6 +368,7 @@ class Currency:
             decimal_places=self._decimal_places,
             decimal_sign=self._decimal_sign,
             grouping_sign=self._grouping_sign,
+            convertion=self._convertion,
             international=self._international)
 
     def __add__(self, other: Any) -> 'Currency':
@@ -388,6 +400,7 @@ class Currency:
             decimal_places=self._decimal_places,
             decimal_sign=self._decimal_sign,
             grouping_sign=self._grouping_sign,
+            convertion=self._convertion,
             international=self._international)
 
     def __bool__(self) -> bool:
@@ -414,6 +427,7 @@ class Currency:
             decimal_places=self._decimal_places,
             decimal_sign=self._decimal_sign,
             grouping_sign=self._grouping_sign,
+            convertion=self._convertion,
             international=self._international)
 
     def __copy__(self) -> 'Currency':
@@ -432,6 +446,7 @@ class Currency:
             decimal_places=self._decimal_places,
             decimal_sign=self._decimal_sign,
             grouping_sign=self._grouping_sign,
+            convertion=self._convertion,
             international=self._international)
 
     def __divmod__(self, other: Any) -> tuple['Currency', 'Currency']:
@@ -466,6 +481,7 @@ class Currency:
                 decimal_places=self._decimal_places,
                 decimal_sign=self._decimal_sign,
                 grouping_sign=self._grouping_sign,
+                convertion=self._convertion,
                 international=self._international),
             self.__class__(
                 amount=remainder,
@@ -477,6 +493,7 @@ class Currency:
                 decimal_places=self._decimal_places,
                 decimal_sign=self._decimal_sign,
                 grouping_sign=self._grouping_sign,
+                convertion=self._convertion,
                 international=self._international))
 
     def __eq__(self, other: Any) -> bool:
@@ -519,6 +536,7 @@ class Currency:
             decimal_places=self._decimal_places,
             decimal_sign=self._decimal_sign,
             grouping_sign=self._grouping_sign,
+            convertion=self._convertion,
             international=self._international)
 
     def __floordiv__(self, other: Any) -> 'Currency':
@@ -551,6 +569,7 @@ class Currency:
             decimal_places=self._decimal_places,
             decimal_sign=self._decimal_sign,
             grouping_sign=self._grouping_sign,
+            convertion=self._convertion,
             international=self._international)
 
     def __ge__(self, other: Any) -> bool:
@@ -684,6 +703,7 @@ class Currency:
             decimal_places=self._decimal_places,
             decimal_sign=self._decimal_sign,
             grouping_sign=self._grouping_sign,
+            convertion=self._convertion,
             international=self._international)
 
     def __mul__(self, other: Any) -> 'Currency':
@@ -711,6 +731,7 @@ class Currency:
             decimal_places=self._decimal_places,
             decimal_sign=self._decimal_sign,
             grouping_sign=self._grouping_sign,
+            convertion=self._convertion,
             international=self._international)
 
     def __ne__(self, other: Any) -> bool:
@@ -740,6 +761,7 @@ class Currency:
             decimal_places=self._decimal_places,
             decimal_sign=self._decimal_sign,
             grouping_sign=self._grouping_sign,
+            convertion=self._convertion,
             international=self._international)
 
     def __pos__(self) -> 'Currency':
@@ -758,6 +780,7 @@ class Currency:
             decimal_places=self._decimal_places,
             decimal_sign=self._decimal_sign,
             grouping_sign=self._grouping_sign,
+            convertion=self._convertion,
             international=self._international)
 
     def __reduce__(self) -> tuple[type, tuple[Any, ...]]:
@@ -779,6 +802,7 @@ class Currency:
                 self._decimal_places,
                 self._decimal_sign,
                 self._grouping_sign,
+                self._convertion,
                 self._international))
 
     def __repr__(self) -> str:
@@ -798,6 +822,7 @@ class Currency:
             f'decimal_places: "{self._decimal_places}", '
             f'decimal_sign: "{self._decimal_sign}", '
             f'grouping_sign: "{self._grouping_sign}", '
+            f'convertion: "{self._convertion}", '
             f'international: {self._international})')
 
     def __round__(self, precision: Optional[int] = None) -> 'Currency':
@@ -820,6 +845,7 @@ class Currency:
             decimal_places=self._decimal_places,
             decimal_sign=self._decimal_sign,
             grouping_sign=self._grouping_sign,
+            convertion=self._convertion,
             international=self._international)
 
     def __str__(self) -> str:
@@ -832,6 +858,9 @@ class Currency:
         converted = f'{round(self._amount, p):,.{p}f}'
         if self._international:
             return f'{self._alpha_code} {converted}'
+        if self._convertion:
+            t = dict(zip('0123456789-', self._convertion))
+            converted = ''.join([t.get(c, c) for c in converted])
         converted = converted.replace('.', 'X').replace(
             ',', self._grouping_sign).replace('X', self._decimal_sign)
         if self._symbol_ahead:
@@ -867,6 +896,7 @@ class Currency:
             decimal_places=self._decimal_places,
             decimal_sign=self._decimal_sign,
             grouping_sign=self._grouping_sign,
+            convertion=self._convertion,
             international=self._international)
 
     def __truediv__(self, other: Any) -> 'Currency':
@@ -898,6 +928,7 @@ class Currency:
             decimal_places=self._decimal_places,
             decimal_sign=self._decimal_sign,
             grouping_sign=self._grouping_sign,
+            convertion=self._convertion,
             international=self._international)
 
     __rmul__: 'Currency' = __mul__
@@ -927,6 +958,9 @@ class Currency:
         converted = f'{round(self._amount, p):,.{p}f}'
         if self._international:
             return f'{self._alpha_code} {converted}'
+        if self._convertion:
+            t = dict(zip('0123456789-', self._convertion))
+            converted = ''.join([t.get(c, c) for c in converted])
         converted = converted.replace('.', 'X').replace(
             ',', self._grouping_sign).replace('X', self._decimal_sign)
         if self._symbol_ahead:
@@ -948,6 +982,11 @@ class Currency:
         """str: alpha_code."""
         return self._alpha_code
 
+    @property
+    def convertion(self) -> str:
+        """str: convertion."""
+        return self._convertion
+
     @property
     def decimal_places(self) -> int:
         """int: decimal_places."""
